sequencetools.yield_all_unordered_pairs_of_sequence
===================================================

.. autofunction:: abjad.tools.sequencetools.yield_all_unordered_pairs_of_sequence.yield_all_unordered_pairs_of_sequence
